@@ -4,5 +4,5 @@ use strict;
 use B::Foreach::Iterator;
 
 for my $key(foo => 10, bar => 20, baz => 30){
-	printf "%s => %s\n", $key => iter_inc;
+	printf "%s => %s\n", $key => iter->next;
 }
